@@ -1,7 +1,7 @@
 package lib::prereqs::only;
 
-our $DATE = '2016-07-08'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-11'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -148,7 +148,7 @@ sub import {
     #    }
     #}
 
-    lib::filter->import(
+    my @lf_args = (
         allow_core    => $allow_core,
         allow_noncore => 0,
         debug         => $debug,
@@ -159,6 +159,8 @@ sub import {
         (allow_re     => $allow_re) x !!(defined $allow_re),
         allow_is_recursive => 1,
     );
+    warn "$dbgh importing lib::filter with arguments: ", join(", ", @lf_args);
+    lib::filter->import(@lf_args);
 }
 
 sub unimport {
@@ -166,7 +168,7 @@ sub unimport {
 }
 
 1;
-# ABSTRACT: Only allow modules specified in prereqs in dist.ini to be locateable/loadable
+# ABSTRACT: Only allow loading modules specified in prereqs in dist.ini
 
 __END__
 
@@ -176,21 +178,33 @@ __END__
 
 =head1 NAME
 
-lib::prereqs::only - Only allow modules specified in prereqs in dist.ini to be locateable/loadable
+lib::prereqs::only - Only allow loading modules specified in prereqs in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.002 of lib::prereqs::only (from Perl distribution lib-prereqs-only), released on 2016-07-08.
+This document describes version 0.003 of lib::prereqs::only (from Perl distribution lib-prereqs-only), released on 2017-01-11.
 
 =head1 SYNOPSIS
 
- % cd perl-Your-Dist
+To test your distribution:
+
+ % cd Your-Dist
  % PERL5OPT=-Mlib::prereqs::only prove -l
 
 To allow RuntimeRecommends prereqs too:
 
  % PERL5OPT=-Mlib::prereqs::only=RuntimeRecommends,1 prove -l
 
+To test script:
+
+ % PERL5OPT=-Mlib::prereqs::only some-script
+
+To test script in your distribution (as well as turn debugging on, and allowing
+core modules even though they are not specified in F<dist.ini>):
+
+ % cd Your-Dist
+ % perl -Mlib::prereqs::only=debug,1,allow_core,1 -Ilib bin/some-script
+
 =head1 DESCRIPTION
 
 This pragma reads the prerequisites found in F<dist.ini>, the modules found in
@@ -203,13 +217,13 @@ Some caveats:
 
 =over
 
-=item * This pragma currently only works via C<PERL5OPT>
+=item * For using with C<prove>, this pragma currently only works via C<PERL5OPT>
 
 Using:
 
  % prove -Mlib::prereqs::only ...
 
-currently does not work.
+currently does not work, because the test script is run in a separate process.
 
 =back
 
@@ -283,7 +297,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
